==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/kok-IN.pl <==
{
  am_pm_abbreviated => [
    "\N{U+092e}.\N{U+092a}\N{U+0942}.",
    "\N{U+092e}.\N{U+0928}\N{U+0902}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "kok-IN",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "dd-MM-y",
  date_format_short => "d-M-yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0933}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0947}\N{U+0928}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+092f}\N{U+0924}\N{U+093e}\N{U+0930}",
  ],
  day_format_narrow => [
    "\N{U+0938}\N{U+094b}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}",
    "\N{U+0917}\N{U+0941}",
    "\N{U+0936}\N{U+0941}",
    "\N{U+0936}\N{U+0947}",
    "\N{U+0906}",
  ],
  day_format_wide => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0933}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0947}\N{U+0928}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+092f}\N{U+0924}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0933}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0947}\N{U+0928}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+092f}\N{U+0924}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0938}\N{U+094b}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}",
    "\N{U+0917}\N{U+0941}",
    "\N{U+0936}\N{U+0941}",
    "\N{U+0936}\N{U+0947}",
    "\N{U+0906}",
  ],
  day_stand_alone_wide => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0933}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0947}\N{U+0928}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+092f}\N{U+0924}\N{U+093e}\N{U+0930}",
  ],
  era_abbreviated => [
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+0936}\N{U+0916}\N{U+093e}",
  ],
  era_narrow => [
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+0936}\N{U+0916}\N{U+093e}",
  ],
  era_wide => [
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+0936}\N{U+0916}\N{U+093e}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%A %d %b %Y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S  %Z",
  language => "Konkani",
  month_format_abbreviated => [
    "\N{U+091c}\N{U+093e}\N{U+0928}\N{U+0947}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0947}\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+090f}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+092f}",
    "\N{U+0906}\N{U+0917}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+094b}\N{U+0935}\N{U+094d}\N{U+0939}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+091c}\N{U+093e}\N{U+0928}\N{U+0947}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0947}\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+090f}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+092f}",
    "\N{U+0906}\N{U+0917}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+094b}\N{U+0935}\N{U+094d}\N{U+0939}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+091c}\N{U+093e}\N{U+0928}\N{U+0947}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0947}\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+090f}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+092f}",
    "\N{U+0906}\N{U+0917}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+094b}\N{U+0935}\N{U+094d}\N{U+0939}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+091c}\N{U+093e}\N{U+0928}\N{U+0947}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0947}\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+090f}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+092f}",
    "\N{U+0906}\N{U+0917}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+094b}\N{U+0935}\N{U+094d}\N{U+0939}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  name => "Konkani India",
  native_language => "\N{U+0915}\N{U+094b}\N{U+0902}\N{U+0915}\N{U+0923}\N{U+0940}",
  native_name => "\N{U+0915}\N{U+094b}\N{U+0902}\N{U+0915}\N{U+0923}\N{U+0940} \N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924}",
  native_script => undef,
  native_territory => "\N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "India",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 32,
}

==> DateTime-Locale-1.20.tar.gz: DateTime-Locale-1.20/share/kok-IN.pl <==
{
  am_pm_abbreviated => [
    "\N{U+092e}.\N{U+092a}\N{U+0942}.",
    "\N{U+092e}.\N{U+0928}\N{U+0902}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' y",
  },
  code => "kok-IN",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "dd-MM-y",
  date_format_short => "d-M-yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0933}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0947}\N{U+0928}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+092f}\N{U+0924}\N{U+093e}\N{U+0930}",
  ],
  day_format_narrow => [
    "\N{U+0938}\N{U+094b}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}",
    "\N{U+0917}\N{U+0941}",
    "\N{U+0936}\N{U+0941}",
    "\N{U+0936}\N{U+0947}",
    "\N{U+0906}",
  ],
  day_format_wide => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0933}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0947}\N{U+0928}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+092f}\N{U+0924}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0933}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0947}\N{U+0928}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+092f}\N{U+0924}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0938}\N{U+094b}",
    "\N{U+092e}\N{U+0902}",
    "\N{U+092c}\N{U+0941}",
    "\N{U+0917}\N{U+0941}",
    "\N{U+0936}\N{U+0941}",
    "\N{U+0936}\N{U+0947}",
    "\N{U+0906}",
  ],
  day_stand_alone_wide => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0933}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0917}\N{U+0941}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0947}\N{U+0928}\N{U+0935}\N{U+093e}\N{U+0930}",
    "\N{U+0906}\N{U+092f}\N{U+0924}\N{U+093e}\N{U+0930}",
  ],
  era_abbreviated => [
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+0936}\N{U+0916}\N{U+093e}",
  ],
  era_narrow => [
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+0936}\N{U+0916}\N{U+093e}",
  ],
  era_wide => [
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+0936}\N{U+0916}\N{U+093e}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%A %d %b %Y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S  %Z",
  language => "Konkani",
  month_format_abbreviated => [
    "\N{U+091c}\N{U+093e}\N{U+0928}\N{U+0947}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0947}\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+090f}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+092f}",
    "\N{U+0906}\N{U+0917}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+094b}\N{U+0935}\N{U+094d}\N{U+0939}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+091c}\N{U+093e}\N{U+0928}\N{U+0947}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0947}\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+090f}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+092f}",
    "\N{U+0906}\N{U+0917}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+094b}\N{U+0935}\N{U+094d}\N{U+0939}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+091c}\N{U+093e}\N{U+0928}\N{U+0947}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0947}\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+090f}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+092f}",
    "\N{U+0906}\N{U+0917}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+094b}\N{U+0935}\N{U+094d}\N{U+0939}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+091c}\N{U+093e}\N{U+0928}\N{U+0947}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0947}\N{U+092c}\N{U+094d}\N{U+0930}\N{U+0941}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+090f}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0932}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+092f}",
    "\N{U+0906}\N{U+0917}\N{U+094b}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+092a}\N{U+094d}\N{U+091f}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0911}\N{U+0915}\N{U+094d}\N{U+091f}\N{U+094b}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+094b}\N{U+0935}\N{U+094d}\N{U+0939}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0921}\N{U+093f}\N{U+0938}\N{U+0947}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  name => "Konkani India",
  native_language => "\N{U+0915}\N{U+094b}\N{U+0902}\N{U+0915}\N{U+0923}\N{U+0940}",
  native_name => "\N{U+0915}\N{U+094b}\N{U+0902}\N{U+0915}\N{U+0923}\N{U+0940} \N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924}",
  native_script => undef,
  native_territory => "\N{U+092d}\N{U+093e}\N{U+0930}\N{U+0924}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "India",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 33,
}
